@@ -1,11 +1,12 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="ca_ES" sourcelanguage="fr_FR">
+<!DOCTYPE TS>
+<TS version="2.1" language="ca_ES" sourcelanguage="fr_FR">
 <context>
     <name>Dialog</name>
     <message>
         <location filename="../pyacidobasic/prelevement.ui" line="14"/>
         <source>Define a sample</source>
-        <translation type="unfinished">Definició d&apos;un assaig</translation>
+        <translation type="unfinished">Definició d'un assaig</translation>
     </message>
     <message>
         <location filename="../pyacidobasic/prelevement.ui" line="45"/>
@@ -156,12 +157,12 @@
     <message>
         <location filename="../pyacidobasic/main.ui" line="708"/>
         <source>make the abscissa range wider</source>
-        <translation type="unfinished">augmentar l&apos;interval de les abscisses</translation>
+        <translation type="unfinished">augmentar l'interval de les abscisses</translation>
     </message>
     <message>
         <location filename="../pyacidobasic/main.ui" line="725"/>
         <source>make the abscissa range narrower</source>
-        <translation type="unfinished">disminuir l&apos;interval de les abscisses</translation>
+        <translation type="unfinished">disminuir l'interval de les abscisses</translation>
     </message>
     <message>
         <location filename="../pyacidobasic/main.ui" line="535"/>
@@ -210,7 +211,7 @@
     </message>
     <message>
         <location filename="../main.ui" line="850"/>
-        <source>d&#xe9;riv&#xe9;e</source>
+        <source>dérivée</source>
         <translation type="obsolete">derivada</translation>
     </message>
     <message>
@@ -260,7 +261,7 @@
     </message>
     <message>
         <location filename="../main.ui" line="508"/>
-        <source>Quantit&#xe9;s</source>
+        <source>Quantités</source>
         <translation type="obsolete">Quantitats</translation>
     </message>
     <message>
@@ -327,22 +328,22 @@
 <context>
     <name>pyacidobasic</name>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="269"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="271"/>
         <source>File to save</source>
         <translation type="unfinished">Fitxer a guardar</translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="269"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="271"/>
         <source>Acidobasic files [*.acb] (*.acb);; All files (*.* *)</source>
         <translation type="unfinished">Fitxers Acidobasic [*.acb] (*.acb);; Qualsevol fitxer (*.* *)</translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="281"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="288"/>
         <source>Version error</source>
         <translation type="unfinished">Error de versió</translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="293"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="300"/>
         <source>About</source>
         <translation type="unfinished">Sobre</translation>
     </message>
@@ -387,8 +388,8 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="281"/>
-        <source>This file is not a valid Pyacidobasic file, version %s.</source>
+        <location filename="../pyacidobasic/mainwindow.py" line="288"/>
+        <source>This file is not a valid Pyacidobasic file, version %s. Error: %s ; %s</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
