@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="en_US" sourcelanguage="fr_FR">
+<!DOCTYPE TS>
+<TS version="2.1" language="en_US" sourcelanguage="fr_FR">
 <context>
     <name>Dialog</name>
     <message>
@@ -24,12 +25,12 @@
     </message>
     <message>
         <location filename="../prelevement.ui" line="14"/>
-        <source>D&#xe9;finition d&apos;un pr&#xe9;l&#xe8;vement</source>
+        <source>Définition d'un prélèvement</source>
         <translation type="obsolete">Define a sample</translation>
     </message>
     <message>
         <location filename="../prelevement.ui" line="45"/>
-        <source>Pr&#xe9;l&#xe8;vement : </source>
+        <source>Prélèvement : </source>
         <translation type="obsolete">Sample: </translation>
     </message>
     <message>
@@ -180,7 +181,7 @@
     </message>
     <message>
         <location filename="../main.ui" line="101"/>
-        <source>Choix des r&#xe9;actifs</source>
+        <source>Choix des réactifs</source>
         <translation type="obsolete">Choose reagents</translation>
     </message>
     <message>
@@ -250,7 +251,7 @@
     </message>
     <message>
         <location filename="../main.ui" line="110"/>
-        <source>Taper quelques lettres du r&#xe9;actif pour le s&#xe9;lectionner plus facilement</source>
+        <source>Taper quelques lettres du réactif pour le sélectionner plus facilement</source>
         <translation type="obsolete">Type in a few charcters of the reagent</translation>
     </message>
     <message>
@@ -295,7 +296,7 @@
     </message>
     <message>
         <location filename="../main.ui" line="344"/>
-        <source>Rouge de m&#xe9;thyle</source>
+        <source>Rouge de méthyle</source>
         <translation type="obsolete">Methyl red</translation>
     </message>
     <message>
@@ -305,7 +306,7 @@
     </message>
     <message>
         <location filename="../main.ui" line="850"/>
-        <source>d&#xe9;riv&#xe9;e</source>
+        <source>dérivée</source>
         <translation type="obsolete">derivative</translation>
     </message>
     <message>
@@ -394,16 +395,16 @@
     <message>
         <location filename="../pyacidobasic/mainwindow.py" line="281"/>
         <source>This file is not a valid Pyacidobasic file, version %s.</source>
-        <translation type="unfinished">This file is not a valid Pyacidobasic file, version %s.</translation>
+        <translation type="obsolete">This file is not a valid Pyacidobasic file, version %s.</translation>
     </message>
     <message>
         <location filename="../phplot.py" line="87"/>
-        <source>Un bug est possible, le d&#xe9;veloppeur a patch&#xe9; le fichier ImageExport du paquet pyqtgraph, et post&#xe9; un rapport de bug. Tant que ce rapport n&apos;est pas trait&#xe9;, il y aura des soucis.</source>
+        <source>Un bug est possible, le développeur a patché le fichier ImageExport du paquet pyqtgraph, et posté un rapport de bug. Tant que ce rapport n'est pas traité, il y aura des soucis.</source>
         <translation type="obsolete">A bug is possible, the developer has patched the file ImageExport in the package pyqtgraph, and posted a bug report. As long as this bug is not fixed, there will be an issue.</translation>
     </message>
     <message>
         <location filename="../mainwindow.py" line="276"/>
-        <source>&#xc0; propos</source>
+        <source>À propos</source>
         <translation type="obsolete">About</translation>
     </message>
     <message>
@@ -422,24 +423,29 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="269"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="271"/>
         <source>File to save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="269"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="271"/>
         <source>Acidobasic files [*.acb] (*.acb);; All files (*.* *)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="281"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="288"/>
         <source>Version error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../pyacidobasic/mainwindow.py" line="293"/>
+        <location filename="../pyacidobasic/mainwindow.py" line="300"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../pyacidobasic/mainwindow.py" line="288"/>
+        <source>This file is not a valid Pyacidobasic file, version %s. Error: %s ; %s</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
