@@ -55,7 +55,7 @@ import pyqtgraph as pg
 import numpy as np
 import PIL.Image
 
-import os.path, pickle, re, sys
+import os.path, pickle, jsonpickle, re, sys
 
 class acidoBasicMainWindow(QMainWindow):
     indicators=['rien.svg.png', 'bbt.svg.png', 'phenolphtaleine.svg.png',
@@ -247,11 +247,13 @@ class acidoBasicMainWindow(QMainWindow):
         Enregistre les données du graphique
         """
         if self.filename:
-            p=pickle.Pickler(open(self.filename,"wb"))
-            p.dump(versionString.encode("utf-8"))
-            burette=self.ui.listWidgetBurette.dump()
-            p.dump(burette)
-            p.dump(self.ui.listWidgetBecher.dump())
+            obj = {
+                "version": versionString,
+                "burette": self.ui.listWidgetBurette,
+                "becher": self.ui.listWidgetBecher,
+            }
+            with open(self.filename, "w") as outfile:
+                outfile.write(jsonpickle.encode(obj, indent=2))
         else:
             self.saveAs()
 
@@ -271,14 +273,19 @@ class acidoBasicMainWindow(QMainWindow):
             self.filename=fname
             p=pickle.Unpickler(open(self.filename,"rb"))
             try:
-                versionString=p.load().decode("utf-8")
-                if versionString!=versionString:
-                    raise EnvironmentError
+                versionString_=p.load().decode("utf-8")
                 self.ui.listWidgetBurette.load(p.load())
                 self.ui.listWidgetBecher.load(p.load())
                 self.updateWindowTitle()
-            except:
-                QMessageBox.warning (self, QApplication.translate("pyacidobasic", "Version error"), QApplication.translate("pyacidobasic", "This file is not a valid Pyacidobasic file, version %s.") % version)
+                self.replot()
+            except pickle.UnpicklingError:
+                obj = jsonpickle.decode(open(fname).read())
+                self.ui.listWidgetBurette.load_from_json(obj)
+                self.ui.listWidgetBecher.load_from_json(obj)
+                self.updateWindowTitle()
+                self.replot()
+            except Exception as err:
+                QMessageBox.warning (self, QApplication.translate("pyacidobasic", "Version error"), QApplication.translate("pyacidobasic", "This file is not a valid Pyacidobasic file, version %s. Error: %s ; %s") % (version,err, type(err)))
 
     def apropos(self):
         """
@@ -451,9 +458,9 @@ class acidoBasicMainWindow(QMainWindow):
         r=np.sin(self.row*np.pi/2)
         v=np.sin(self.row*np.pi/3)
         b=np.sin(self.row*np.pi/5)
-        r=(1+r)/2*255
-        v=(1+v)/2*255
-        b=(1+b)/2*255
+        r=round((1+r)/2*255)
+        v=round((1+v)/2*255)
+        b=round((1+b)/2*255)
         return QColor(r,v,b)
 
     def ajouteSolutes(self):
